@@ -46,7 +46,7 @@ void test_matrix()
   std::cout << f << std::endl;
 
   // Construction of FieldMatrix from ScaledIdentityMatrix
-  FieldMatrix<K,n,n> AFM DUNE_UNUSED = FieldMatrix<K,n,n>(A);
+  [[maybe_unused]] FieldMatrix<K,n,n> AFM = FieldMatrix<K,n,n>(A);
 }
 
 int main()
